km3pipe.dataclasses.TrackSeries
===============================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: TrackSeries

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrackSeries.__init__
      ~TrackSeries.deserialise
      ~TrackSeries.from_aanet
      ~TrackSeries.from_arrays
      ~TrackSeries.from_table
      ~TrackSeries.get_len
      ~TrackSeries.get_usr_item
      ~TrackSeries.next
      ~TrackSeries.serialise
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TrackSeries.bjorkeny
      ~TrackSeries.dir
      ~TrackSeries.dtype
      ~TrackSeries.energy
      ~TrackSeries.highest_energetic_muon
      ~TrackSeries.id
      ~TrackSeries.interaction_channel
      ~TrackSeries.is_cc
      ~TrackSeries.length
      ~TrackSeries.pos
      ~TrackSeries.time
      ~TrackSeries.type
   
   